@@ -55,7 +55,7 @@ static ClientData drcSubClientData;
 
 static DRCCookie drcSubcellCookie = {
     0, 0, 0, 0,
-    { 0 }, { 0 },
+    { {0} }, { {0} },
     0, 0, 0,
     DRC_SUBCELL_OVERLAP_TAG,
     (DRCCookie *) NULL
@@ -68,7 +68,7 @@ static DRCCookie drcSubcellCookie = {
 
 static DRCCookie drcInSubCookie = {
     0, 0, 0, 0,
-    { 0 }, { 0 },
+    { {0} }, { {0} },
     0, 0, 0,
     DRC_IN_SUBCELL_TAG,
     (DRCCookie *) NULL
@@ -82,7 +82,7 @@ static DRCCookie drcInSubCookie = {
 
 static DRCCookie drcOffGridCookie = {
     0, 0, 0, 0,
-    { 0 }, { 0 },
+    { {0} }, { {0} },
     0, 0, 0,
     DRC_OFFGRID_TAG,
     (DRCCookie *) NULL
@@ -965,5 +965,5 @@ drcIncCount(def, area, rule, count)
     DRCCookie *rule;
     int *count;
 {
-    *count++;
+    (*count)++;
 }
