@@ -282,7 +282,7 @@ hash(table, key)
 HashEntry *
 HashLookOnly(table, key)
     HashTable *table;	/* Hash table to search. */
-    char *key;			/* Interpreted according to table->ht_ptrKeys
+    const char *key;		/* Interpreted according to table->ht_ptrKeys
 				 * as described in HashInit()'s comments.
 				 */
 {
@@ -352,7 +352,7 @@ next:
 HashEntry *
 HashFind(table, key)
     HashTable *table;	/* Hash table to search. */
-    char *key;			/* Interpreted according to table->ht_ptrKeys
+    const char *key;		/* Interpreted according to table->ht_ptrKeys
 				 * as described in HashInit()'s comments.
 				 */
 {
@@ -577,7 +577,7 @@ HashStats(table)
 void
 HashRemove(table, key)
     HashTable *table;	/* Hash table to search. */
-    char *key;			/* Interpreted according to table->ht_ptrKeys
+    const char *key;		/* Interpreted according to table->ht_ptrKeys
 				 * as described in HashInit()'s comments.
 				 */
 {
@@ -692,9 +692,13 @@ HashKill(table)
     for (hp = table->ht_table, hend = &hp[table->ht_size]; hp < hend; hp++)
 	for (h = *hp; h != NIL; h = h->h_next)
 	{
+	    const void *p;
 	    freeMagic((char *) h);
 	    if (killFn)
-		(*killFn)(h->h_key.h_ptr);
+	    {
+		p = h->h_key.h_ptr;
+		(*killFn)((void *)p);
+	    }
 	}
     freeMagic((char *) table->ht_table);
 
