@@ -19,8 +19,8 @@
  * rcsid[]="$Header: /usr/cvsroot/magic-8.0/utils/signals.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
  */
 
-#ifndef _MAGSIGNAL_H
-#define _MAGSIGNAL_H
+#ifndef _MAGIC__UTILS__SIGNALS_H
+#define _MAGIC__UTILS__SIGNALS_H
 
 #include "utils/magic.h"
 
@@ -59,4 +59,4 @@ extern void SigRemoveTimer();
 
 extern sigRetVal sigOnInterrupt();
 
-#endif /* _MAGSIGNAL_H */
+#endif /* _MAGIC__UTILS__SIGNALS_H */
